==> ktexteditor-5.4.0.zip: ktexteditor-5.4.0/src/mode/katemodeconfigpage.h <==
/*  This file is part of the KDE libraries and the Kate part.
 *
 *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef KATE_MODECONFIGPAGE_H__
#define KATE_MODECONFIGPAGE_H__

#include <QStringList>
#include <QPointer>
#include <QHash>

#include "katedialogs.h"
#include "katemodemanager.h"

namespace Ui
{
class FileTypeConfigWidget;
}

class ModeConfigPage : public KateConfigPage
{
    Q_OBJECT

public:
    explicit ModeConfigPage(QWidget *parent);
    ~ModeConfigPage();
    virtual QString name() const;

public Q_SLOTS:
    void apply();
    void reload();
    void reset();
    void defaults();

private Q_SLOTS:
    void update();
    void deleteType();
    void newType();
    void typeChanged(int type);
    void showMTDlg();
    void save();
    void hlDownload();

private:
    Ui::FileTypeConfigWidget *ui;

    QList<KateFileType *> m_types;
    int m_lastType;
};

#endif

==> ktexteditor-5.39.0.zip: ktexteditor-5.39.0/src/mode/katemodeconfigpage.h <==
/*  This file is part of the KDE libraries and the Kate part.
 *
 *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef KATE_MODECONFIGPAGE_H__
#define KATE_MODECONFIGPAGE_H__

#include <QStringList>
#include <QPointer>
#include <QHash>

#include "katedialogs.h"
#include "katemodemanager.h"

namespace Ui
{
class FileTypeConfigWidget;
}

class ModeConfigPage : public KateConfigPage
{
    Q_OBJECT

public:
    explicit ModeConfigPage(QWidget *parent);
    ~ModeConfigPage();
    QString name() const Q_DECL_OVERRIDE;

public Q_SLOTS:
    void apply() Q_DECL_OVERRIDE;
    void reload() Q_DECL_OVERRIDE;
    void reset() Q_DECL_OVERRIDE;
    void defaults() Q_DECL_OVERRIDE;

private Q_SLOTS:
    void update();
    void deleteType();
    void newType();
    void typeChanged(int type);
    void showMTDlg();
    void save();
    void hlDownload();

private:
    Ui::FileTypeConfigWidget *ui;

    QList<KateFileType *> m_types;
    int m_lastType;
};

#endif
